gauzz_binom package

Description
The application calculates the mean, stdev, PDF, etc., of Binomial and Guassian distributoins.

Dependencies
Python: >=3.6
Matplotlib: 2.1.0

Installation
pip install 

Executing the program
from distributions import Binomial, Gaussian
Binomial(prob=.5, size=20): default values provided
	prob = float
    size = int
    
Gaussian(mu=0, sigma=1): default values provided
	mu, sigma = int

Help
Reach out to the author(s) using the address(es)

Authors
Hakeem Mabby: email => hakeem@example.com

Version: 1.1

Acknowlegments:
Bertelsmann, AI Programming with Python
Udacity